| svy.varcoef | R Documentation |
Computes the sandwich variance estimator for a generalised linear model fitted to data from a complex sample survey. Designed to be used internally by svyglm.
svy.varcoef(glm.object, design,std.errors = c("linearized",
"Bell-McCaffrey", "Bell-McCaffrey-2"), degf = FALSE)
glm.object |
A |
design |
A |
std.errors |
The kind of standard errors to compute |
degf |
Whether to compute the adjusted degrees of freedom along with Bell-McCaffrey standard errors |
A variance matrix
Thomas Lumley
svyglm,svydesign, svyCprod
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.