Computes the sandwich variance estimator for a generalised linear model fitted to data from a complex sample survey. Designed to be used internally by svyglm.
svy.varcoef(glm.object, design,std.errors = c("linearized",
"Bell-McCaffrey", "Bell-McCaffrey-2"), degf = FALSE)A variance matrix
A glm object
A survey.design object
The kind of standard errors to compute
Whether to compute the adjusted degrees of freedom along with Bell-McCaffrey standard errors
Thomas Lumley
svyglm,svydesign, svyCprod