svyCprod(x, strata, psu, fpc, lonely.psu=getOption("survey.lonely.psu"))NULLNULLNULL"remove", "adjust",
"fail". See Details belowThe variance formula gives 0/0 if a stratum contains only one sampling
unit. The options to handle this are "fail" to give an error,
"remove" to give a variance contribution of 0 for the stratum,
and "adjust" to center the stratum at the grand mean rather than
the stratum mean. The choice is controlled by setting
options(survey.lonely.psu). If this is not done the factory
default is "fail". Using "adjust" is conservative, and it
would often be better to combine strata in some intelligent way. The
"remove" option is included because it might be needed for
compatibility.
svydesign, svy.varcoef