The "logit" method fits a logistic regression model and computes a
Wald-type interval on the log-odds scale, which is then transformed to
the probability scale.
The "likelihood" method uses the (Rao-Scott) scaled chi-squared distribution
for the loglikelihood from a binomial distribution.
The "asin" method uses the variance-stabilising transformation
for the binomial distribution, the arcsine square root, and then
back-transforms the interval to the probability scale
The "beta" method uses the incomplete beta function as in
binom.test, with an effective sample size based on the
estimated variance of the proportion. (Korn and Graubard, 1998)
The "xlogit" method uses a logit transformation of the mean and
then back-transforms to the probablity scale. This appears to be the
method used by SUDAAN and SPSS COMPLEX SAMPLES and the Stata option
citype(logit). The results are nearly identical to the "logit" method
except when replicate weights are used, as in that case "logit"
estimates the variance of the transformed proportion using the replicate weights,
whereas "xlogit" uses the replicate weights to estimate
the variance of the proportion.
The "wilson" method is the Wilson score interval, which inverts
the coverage probability statement using the true probability rather
than the estimated probability, which results in a quadratic equation
for the estimated probability. This interval is contained in [0,1].
The "mean" method is a Wald-type interval on the probability
scale, the same as confint(svymean())
All methods undercover for probabilities close enough to zero or one,
but "mean" and "asin" are noticeably
worse than the others. None of the methods will work when the
observed proportion is exactly 0 or 1.
The confint method extracts the confidence interval; the
vcov and SE methods just report the variance or standard
error of the mean.