update.survey.design(object, vars = ~., ...)survey.design objectsurvey.design objectA formula should typically have a . on the right-hand side to indicate that the current variables are to be retained. When vars is an expression the current variables are automatically retained.
svydesign